Subroutine
==========

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. autoclass:: moderngl.Subroutine

.. autoattribute:: Subroutine.index
.. autoattribute:: Subroutine.name

.. toctree::
    :maxdepth: 2
